@@ -78,8 +78,13 @@ class CentralReachCore(SitesCore):
                         )
 
                 self.wait_element_and_refresh('//span[text()="Favorites"]', is_need_screenshot=False)
+
+                if self.does_element_displayed('//span[text()="Continue To Login"]'):
+                    self.click('//span[text()="Continue To Login"]')
+
                 self.is_site_available = self.browser.does_page_contain_element('//span[text()="Favorites"]')
                 self.base_url: str = self.get_base_url(self.browser.get_location())
+
                 return self.is_site_available
             except ScheduledMaintenance as ex:
                 raise ex
